@@ -15,7 +15,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRALN(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "BUS_ADRALN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -27,7 +27,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRERR(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "BUS_ADRERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -39,7 +39,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AO(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "BUS_MCEERR_AO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -51,7 +51,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AR(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "BUS_MCEERR_AR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -63,7 +63,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCERR_(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "BUS_MCERR_ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -75,7 +75,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_OBJERR(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "BUS_OBJERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -87,7 +87,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_CONTINUED(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "CLD_CONTINUED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -99,7 +99,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_DUMPED(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "CLD_DUMPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -111,7 +111,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_EXITED(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "CLD_EXITED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -123,7 +123,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_KILLED(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "CLD_KILLED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -135,7 +135,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_STOPPED(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "CLD_STOPPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -147,7 +147,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_TRAPPED(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "CLD_TRAPPED is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -159,7 +159,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTDIV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -171,7 +171,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTINV(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTINV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -183,7 +183,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTOVF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -195,7 +195,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTRES(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTRES is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -207,7 +207,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTSUB(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTSUB is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -219,7 +219,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTUND(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_FLTUND is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -231,7 +231,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_INTDIV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -243,7 +243,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FPE_INTOVF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -255,7 +255,7 @@ int32_t SPVM__Sys__Signal__Constant__FUTEX_WAIT(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "FUTEX_WAIT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -267,7 +267,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_BADSTK(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_BADSTK is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -279,7 +279,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_COPROC(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_COPROC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -291,7 +291,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLADR(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_ILLADR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -303,7 +303,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPC(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_ILLOPC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -315,7 +315,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPN(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_ILLOPN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -327,7 +327,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLTRP(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_ILLTRP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -339,7 +339,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVOPC(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_PRVOPC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -351,7 +351,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVREG(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "ILL_PRVREG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -363,7 +363,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_ERR(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "POLL_ERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -375,7 +375,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_HUP(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "POLL_HUP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -387,7 +387,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_IN(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "POLL_IN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -399,7 +399,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_MSG(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "POLL_MSG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -411,7 +411,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_OUT(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "POLL_OUT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -423,7 +423,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_PRI(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "POLL_PRI is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -435,7 +435,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_SIGIO(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_SIGIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -447,7 +447,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_ASYNCIO(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "SI_ASYNCIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -459,7 +459,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_KERNEL(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_KERNEL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -471,7 +471,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_MESGQ(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_MESGQ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -483,7 +483,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_QUEUE(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_QUEUE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -495,7 +495,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_TIMER(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_TIMER is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -507,7 +507,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_TKILL(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SI_TKILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -519,7 +519,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_USER(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SI_USER is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -531,7 +531,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRANCH(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "TRAP_BRANCH is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -543,7 +543,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRKPT(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "TRAP_BRKPT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -555,7 +555,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_HWBKPT(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "TRAP_HWBKPT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -567,7 +567,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_TRACE(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "TRAP_TRACE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -579,7 +579,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGABRT(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGABRT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -591,7 +591,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGALRM(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGALRM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -603,7 +603,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGBUS(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGBUS is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -615,7 +615,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGCHLD(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGCHLD is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -627,7 +627,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGCONT(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGCONT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -639,7 +639,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGFPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGFPE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -651,7 +651,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGHUP(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGHUP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -663,7 +663,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -675,7 +675,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGINT(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGINT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -687,7 +687,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGIO(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGIO is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -699,7 +699,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGKILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGKILL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -711,7 +711,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPIPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGPIPE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -723,7 +723,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPROF(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGPROF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -735,7 +735,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPWR(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGPWR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -747,7 +747,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGQUIT(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGQUIT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -759,7 +759,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMAX(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SIGRTMAX is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -771,7 +771,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMIN(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SIGRTMIN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -783,7 +783,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSEGV(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGSEGV is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -795,7 +795,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTKFLT(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SIGSTKFLT is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -807,7 +807,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTOP(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGSTOP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -819,7 +819,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSYS(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGSYS is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -831,7 +831,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTERM(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGTERM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -843,7 +843,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTRAP(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGTRAP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -855,7 +855,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTSTP(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGTSTP is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -867,7 +867,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGTTIN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -879,7 +879,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTOU(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGTTOU is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -891,7 +891,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGURG(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGURG is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -903,7 +903,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR1(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGUSR1 is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -915,7 +915,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR2(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGUSR2 is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -927,7 +927,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGVTALRM(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SIGVTALRM is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -939,7 +939,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGWINCH(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "SIGWINCH is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -951,7 +951,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGXCPU(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGXCPU is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -963,7 +963,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGXFSZ(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIGXFSZ is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -975,7 +975,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_DFL(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIG_DFL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -987,7 +987,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_ERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIG_ERR is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -999,7 +999,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_IGN(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 #else
   env->die(env, stack, "SIG_IGN is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
