@@ -1,14 +1,6 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
-#ifdef __linux__
-  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
-  #define _XOPEN_SOURCE 700
-
-  // Enable BSD and System V extensions
-  #define _DEFAULT_SOURCE
-#endif
-
 // Windows 8.1+
 #define _WIN32_WINNT 0x0603
 
@@ -29,7 +21,7 @@
 static const char* FILE_NAME = "Sys/Socket/AddrinfoLinkedList.c";
 
 int32_t SPVM__Sys__Socket__AddrinfoLinkedList__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
+
   void* obj_addrinfo = stack[0].oval;
   
   struct addrinfo* st_addrinfo = env->get_pointer(env, stack, obj_addrinfo);
@@ -44,8 +36,10 @@ int32_t SPVM__Sys__Socket__AddrinfoLinkedList__DESTROY(SPVM_ENV* env, SPVM_VALUE
 }
 
 int32_t SPVM__Sys__Socket__AddrinfoLinkedList__to_array(SPVM_ENV* env, SPVM_VALUE* stack) {
+  (void)env;
+  (void)stack;
   
-  int32_t error_id = 0;
+  int32_t e = 0;
   
   void* obj_addrinfo = stack[0].oval;
   
@@ -65,8 +59,10 @@ int32_t SPVM__Sys__Socket__AddrinfoLinkedList__to_array(SPVM_ENV* env, SPVM_VALU
     }
   }
   
-  void* obj_addrinfos = env->new_object_array_by_name(env, stack, "Sys::Socket::Addrinfo", length, &error_id, __func__, FILE_NAME, __LINE__);
-  if (error_id) { return error_id; }
+  int32_t addrinfo_basic_type_id = env->get_basic_type_id_by_name(env, stack, "Sys::Socket::Addrinfo", &e, __func__, FILE_NAME, __LINE__);
+  if (e) { return e; }
+  
+  void* obj_addrinfos = env->new_object_array(env, stack, addrinfo_basic_type_id, length);
   
   int32_t index = 0;
   {
@@ -77,11 +73,11 @@ int32_t SPVM__Sys__Socket__AddrinfoLinkedList__to_array(SPVM_ENV* env, SPVM_VALU
         int32_t fields_length = 1;
         
         struct addrinfo* tmp_st_addrinfo = NULL;
-        tmp_st_addrinfo = env->new_memory_block(env, stack, sizeof(struct addrinfo));
+        tmp_st_addrinfo = env->new_memory_stack(env, stack, sizeof(struct addrinfo));
         memcpy(tmp_st_addrinfo, cur_st_addrinfo, sizeof(struct addrinfo));
         
-        void* obj_addrinfo = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Addrinfo", tmp_st_addrinfo, &error_id, __func__, FILE_NAME, __LINE__);
-        if (error_id) { return error_id; }
+        void* obj_addrinfo = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Addrinfo", tmp_st_addrinfo, &e, __func__, FILE_NAME, __LINE__);
+        if (e) { return e; }
         
         env->set_elem_object(env, stack, obj_addrinfos, index, obj_addrinfo);
         
