@@ -15,7 +15,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCKS_PER_SEC(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 #else
   env->die(env, stack, "CLOCKS_PER_SEC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -27,7 +27,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_BOOTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 #else
   env->die(env, stack, "CLOCK_BOOTTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -39,7 +39,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_HIGHRES(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "CLOCK_HIGHRES is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -51,7 +51,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "CLOCK_MONOTONIC is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -63,7 +63,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_COARSE(SPVM_ENV* env, SPVM_VA
   return 0;
 #else
   env->die(env, stack, "CLOCK_MONOTONIC_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -75,7 +75,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_FAST(SPVM_ENV* env, SPVM_VALU
   return 0;
 #else
   env->die(env, stack, "CLOCK_MONOTONIC_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -87,7 +87,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_PRECISE(SPVM_ENV* env, SPVM_V
   return 0;
 #else
   env->die(env, stack, "CLOCK_MONOTONIC_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -99,7 +99,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_MONOTONIC_RAW(SPVM_ENV* env, SPVM_VALUE
   return 0;
 #else
   env->die(env, stack, "CLOCK_MONOTONIC_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -111,7 +111,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROCESS_CPUTIME_ID(SPVM_ENV* env, SPVM_
   return 0;
 #else
   env->die(env, stack, "CLOCK_PROCESS_CPUTIME_ID is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -123,7 +123,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "CLOCK_PROF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -135,7 +135,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 #else
   env->die(env, stack, "CLOCK_REALTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -147,7 +147,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_COARSE(SPVM_ENV* env, SPVM_VAL
   return 0;
 #else
   env->die(env, stack, "CLOCK_REALTIME_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -159,7 +159,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_FAST(SPVM_ENV* env, SPVM_VALUE
   return 0;
 #else
   env->die(env, stack, "CLOCK_REALTIME_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -171,7 +171,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_PRECISE(SPVM_ENV* env, SPVM_VA
   return 0;
 #else
   env->die(env, stack, "CLOCK_REALTIME_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -183,7 +183,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_REALTIME_RAW(SPVM_ENV* env, SPVM_VALUE*
   return 0;
 #else
   env->die(env, stack, "CLOCK_REALTIME_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -195,7 +195,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SECOND(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "CLOCK_SECOND is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -207,7 +207,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_SOFTTIME(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 #else
   env->die(env, stack, "CLOCK_SOFTTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -219,7 +219,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_THREAD_CPUTIME_ID(SPVM_ENV* env, SPVM_V
   return 0;
 #else
   env->die(env, stack, "CLOCK_THREAD_CPUTIME_ID is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -231,7 +231,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_TIMEOFDAY(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "CLOCK_TIMEOFDAY is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -243,7 +243,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 #else
   env->die(env, stack, "CLOCK_UPTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -255,7 +255,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_COARSE(SPVM_ENV* env, SPVM_VALUE
   return 0;
 #else
   env->die(env, stack, "CLOCK_UPTIME_COARSE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -267,7 +267,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_FAST(SPVM_ENV* env, SPVM_VALUE*
   return 0;
 #else
   env->die(env, stack, "CLOCK_UPTIME_FAST is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -279,7 +279,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_PRECISE(SPVM_ENV* env, SPVM_VALU
   return 0;
 #else
   env->die(env, stack, "CLOCK_UPTIME_PRECISE is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -291,7 +291,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_UPTIME_RAW(SPVM_ENV* env, SPVM_VALUE* s
   return 0;
 #else
   env->die(env, stack, "CLOCK_UPTIME_RAW is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -303,7 +303,7 @@ int32_t SPVM__Sys__Time__Constant__CLOCK_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "CLOCK_VIRTUAL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -315,7 +315,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_PROF(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "ITIMER_PROF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -327,7 +327,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REAL(SPVM_ENV* env, SPVM_VALUE* stack)
   return 0;
 #else
   env->die(env, stack, "ITIMER_REAL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -339,7 +339,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_REALPROF(SPVM_ENV* env, SPVM_VALUE* st
   return 0;
 #else
   env->die(env, stack, "ITIMER_REALPROF is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -351,7 +351,7 @@ int32_t SPVM__Sys__Time__Constant__ITIMER_VIRTUAL(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 #else
   env->die(env, stack, "ITIMER_VIRTUAL is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
@@ -363,7 +363,7 @@ int32_t SPVM__Sys__Time__Constant__TIMER_ABSTIME(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 #else
   env->die(env, stack, "TIMER_ABSTIME is not defined on this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
 }
\ No newline at end of file
